import { inherits as _inherits, createSuper as _createSuper, createClass as _createClass, classCallCheck as _classCallCheck, defineProperty as _defineProperty, assertThisInitialized as _assertThisInitialized, get as _get, getPrototypeOf as _getPrototypeOf } from "../../_virtual/_rollupPluginBabelHelpers.js";
import SubTitles from "xgplayer-subtitles";
import util from "../../utils/util.js";
import { PLAYER_FOCUS, PLAYER_BLUR } from "../../events.js";
import "../../utils/debug.js";
import Plugin from "../../plugin/plugin.js";
function formatList(list) {
  var defaultIndex = -1;
  list.forEach(function(item, index) {
    if (!item.id && !item.language) {
      item.id = index;
    }
    item.id = String(item.id);
    !item.url && (item.url = item.src);
    !item.text && (item.text = item.label);
    !item.language && (item.language = item.srclang);
    item.isDefault === void 0 && (item.isDefault = item.default || false);
    if (item.isDefault || item.default) {
      if (defaultIndex < 0) {
        defaultIndex = index;
      } else {
        item.isDefault = item.default = false;
      }
    }
  });
  return defaultIndex;
}
function checkIsSame(src, dist) {
  var isIdS = util.isNotNull(src.id) && util.isNotNull(dist.id) && src.id === dist.id;
  var isLS = util.isNotNull(src.language) && util.isNotNull(dist.language) && src.language === dist.language;
  return isIdS || isLS;
}
var TextTrackParse = /* @__PURE__ */ function(_BasePlugin) {
  _inherits(TextTrackParse2, _BasePlugin);
  var _super = _createSuper(TextTrackParse2);
  function TextTrackParse2() {
    var _this;
    _classCallCheck(this, TextTrackParse2);
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    _this = _super.call.apply(_super, [this].concat(args));
    _defineProperty(_assertThisInitialized(_this), "_onOff", function() {
      _this.switchOffSubtitle();
    });
    _defineProperty(_assertThisInitialized(_this), "_onChange", function(data) {
      var _curIndex = _this.getSubTitleIndex(_this.config.list, data);
      if (_curIndex < 0) {
        return;
      }
      _this.updateCurItem(_curIndex, data);
    });
    _defineProperty(_assertThisInitialized(_this), "_onUpdate", function(text) {
      if (!text || text.length < 1) {
        return;
      }
      var retText = text.map(function(item) {
        return {
          startTime: item.start,
          endTime: item.end,
          text: item.text.length > 0 ? item.text[0] : "",
          textTag: item.textTag
        };
      });
      if (_this._updateCallback) {
        _this._updateCallback(retText[0]);
      }
      _this.emit("subtitle_update", retText[0]);
    });
    _defineProperty(_assertThisInitialized(_this), "_onListReset", function(data) {
      _this.updateList(data);
    });
    return _this;
  }
  _createClass(TextTrackParse2, [{
    key: "afterCreate",
    value: function afterCreate() {
      this._initExtSubTitle();
      this._updateCallback = null;
    }
  }, {
    key: "_initExtSubTitle",
    value: function _initExtSubTitle(defaultIndex) {
      var _this$config = this.config, list = _this$config.list, style = _this$config.style, isDefaultOpen = _this$config.isDefaultOpen, updateMode = _this$config.updateMode, renderMode = _this$config.renderMode;
      if (isDefaultOpen && defaultIndex < 0 && list.length > 0) {
        defaultIndex = 0;
        list[0].isDefault = true;
      }
      var config = {
        subTitles: list,
        defaultOpen: isDefaultOpen,
        updateMode,
        renderMode,
        debugger: this.config.debugger,
        domRender: false
      };
      Object.keys(style).map(function(key) {
        config[key] = style[key];
      });
      var _needPos = !this.playerConfig.marginControls && this.player.controls.root;
      if (_needPos) {
        this.on(PLAYER_FOCUS, this.onPlayerFocus);
        this.on(PLAYER_BLUR, this.onPlayerBlur);
      }
      var player = this.player;
      if (!player._subTitles) {
        player._subTitles = new SubTitles(config);
        player._subTitles.attachPlayer(this.player);
      } else {
        player._subTitles._isOpen && (defaultIndex = this.getSubTitleIndex(this.config.list, player._subTitles.currentText));
      }
      this.subTitles = player._subTitles;
      this.subTitles.on("off", this._onOff);
      this.subTitles.on("change", this._onChange);
      this.subTitles.on("update", this._onUpdate);
      this.subTitles.on("reset", this._onListReset);
      if (style.follow && this.subTitles.root) {
        util.addClass(this.subTitles.root, "follow-control");
      }
    }
  }, {
    key: "show",
    value: function show() {
      if (!this.config.list || this.config.list.length < 1) {
        return;
      }
      util.addClass(this.root, "show");
    }
  }, {
    key: "getSubTitleIndex",
    value: function getSubTitleIndex(list) {
      var subtitle = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {
        id: "",
        language: ""
      };
      var cIndex = -1;
      if (!subtitle || !subtitle.id && !subtitle.language) {
        return cIndex;
      }
      list.forEach(function(item, index) {
        if (checkIsSame(item, subtitle)) {
          cIndex = index;
        }
      });
      return cIndex;
    }
  }, {
    key: "updateSubtitles",
    value: function updateSubtitles() {
      var list = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : [];
      var updateCallback = arguments.length > 1 ? arguments[1] : void 0;
      var needRemove = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : true;
      if (!list) {
        return;
      }
      if (util.typeOf(list) === "String") {
        list = [{
          id: parseInt(Math.random() * 100),
          isDefault: true,
          url: list
        }];
      }
      if (updateCallback) {
        this._updateCallback = updateCallback;
      }
      this.updateList({
        list
      });
      this.subTitles && this.subTitles.setSubTitles(this.config.list, this.curIndex > -1, needRemove);
    }
  }, {
    key: "updateList",
    value: function updateList() {
      var data = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
      if (!data.list) {
        return;
      }
      var nList = [];
      data.list.forEach(function(item) {
        nList.push(item);
      });
      var defaultIndex = formatList(nList);
      if (data.isOpen) {
        this.curIndex = defaultIndex;
        this.curItem = defaultIndex > -1 ? nList[defaultIndex] : null;
      } else {
        this.curIndex = -1;
        this.curItem = null;
      }
      this.config.list = nList;
      if (nList.length === 0) {
        this.switchOffSubtitle();
      }
    }
  }, {
    key: "switchSubTitle",
    value: function switchSubTitle() {
      var subtitle = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {
        id: "",
        language: ""
      };
      var cIndex = this.getSubTitleIndex(this.config.list, subtitle);
      if (cIndex < 0) {
        return;
      }
      this.subTitles.switch(subtitle).catch(function(e) {
      });
    }
  }, {
    key: "switchOffSubtitle",
    value: function switchOffSubtitle(e) {
      this.emit("subtitle_change", {
        off: true,
        isListUpdate: false,
        list: []
      });
      this.lastIndex = this.curIndex;
      this.curIndex = -1;
      this.curItem = null;
      this.switchIconState(false);
    }
  }, {
    key: "switchOnSubtitle",
    value: function switchOnSubtitle() {
      var list = this.config.list;
      var _sub = this.lastIndex > -1 ? this.lastIndex : 0;
      var _item = list[_sub];
      this.switchIconState(true);
      this.switchSubTitle(_item);
    }
  }, {
    key: "destroy",
    value: function destroy() {
      if (this.subTitles) {
        this.subTitles.destroy();
        this.subTitles = null;
      }
      _get(_getPrototypeOf(TextTrackParse2.prototype), "destroy", this).call(this);
    }
  }], [{
    key: "pluginName",
    get: function get() {
      return "texttrack";
    }
  }, {
    key: "defaultConfig",
    get: function get() {
      return {
        index: 6,
        list: [],
        isDefaultOpen: true,
        style: {
          follow: true,
          mode: "stroke",
          followBottom: 50,
          fitVideo: true,
          offsetBottom: 2,
          baseSizeX: 49,
          baseSizeY: 28,
          minSize: 16,
          minMobileSize: 13,
          line: "double",
          fontColor: "#fff"
        },
        closeText: {
          text: "\u4E0D\u5F00\u542F",
          iconText: "\u5B57\u5E55"
        },
        needCloseText: true,
        className: "xgplayer-texttrack",
        hidePortrait: false,
        isShowIcon: true,
        renderMode: "normal",
        mode: "external",
        debugger: false
      };
    }
  }]);
  return TextTrackParse2;
}(Plugin);
export { TextTrackParse as default };
